@@ -475,12 +475,27 @@ class SQLCli(object):
         if len(m_serverurllist) == 0:
             raise SQLCliException("Missed correct url in connect command.")
         m_jdbcprop = m_serverurllist[0]
-        if len(m_serverurllist) >= 2:
+        if len(m_serverurllist) >= 3:
+            # //IP:Port/Service
             self.db_service_name = m_serverurllist[2]
+            self.db_host = m_serverurllist[1]
+            self.db_port = ""
+        elif len(m_serverurllist) >= 2:
+            # //IP:Port:Service
+            # //IP/Service
+            m_serverparameter = m_serverurllist[1].split(':')
+            if len(m_serverparameter) >= 2:
+                self.db_service_name = m_serverparameter[-1]
+                self.db_host = ':'.join(m_serverparameter[:-1])
+                self.db_port = ""
+            else:
+                self.db_host = m_serverurllist[1]
+                self.db_port = ""
+                self.db_service_name = ""
         else:
             self.db_service_name = ""
-        self.db_host = m_serverurllist[1]
-        self.db_port = ""
+            self.db_host = ""
+            self.db_port = ""
 
         # 处理JDBC属性
         m_jdbcproplist = shlex.shlex(m_jdbcprop)
@@ -502,14 +517,7 @@ class SQLCli(object):
         # 连接数据库
         try:
             if self.db_conntype == 'JDBC':   # JDBC 连接数据库
-                # https://github.com/jpype-project/jpype/issues/290
-                # jpype bug, when run jpype in multithread
-                if jpype.isJVMStarted() and not jpype.isThreadAttachedToJVM():
-                    jpype.attachThreadToJVM()
-                    jpype.java.lang.Thread.currentThread().setContextClassLoader(
-                        jpype.java.lang.ClassLoader.getSystemClassLoader())
-
-                # 加载所有的Jar包， jaydebeapi将根据class的名字加载指定的文件
+                # 加载所有的Jar包， 根据class的名字加载指定的文件
                 m_JarList = []
                 m_driverclass = ""
                 m_JDBCURL = ""
